==> jc-1.4.0.tar.gz: soot/Singletons__24Global.h <==
// public final class soot.Singletons$Global

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 47e789a7286ce13e soot_Singletons__24Global

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_Singletons__24Global_H_
#define _JC_soot_Singletons__24Global_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons$object;
struct _jc_soot_Singletons__241$object;

// Typedefs
typedef struct _jc_soot_Singletons__24Global$sub_refs	_jc_soot_Singletons__24Global$sub_refs;
typedef struct _jc_soot_Singletons__24Global$sub_nonrefs	_jc_soot_Singletons__24Global$sub_nonrefs;
typedef struct _jc_soot_Singletons__24Global$refs	_jc_soot_Singletons__24Global$refs;
typedef struct _jc_soot_Singletons__24Global$nonrefs	_jc_soot_Singletons__24Global$nonrefs;
typedef struct _jc_soot_Singletons__24Global$object	_jc_soot_Singletons__24Global$object;

typedef const struct _jc_soot_Singletons__24Global$vmethods	_jc_soot_Singletons__24Global$vmethods;
typedef const struct _jc_soot_Singletons__24Global$vtable	_jc_soot_Singletons__24Global$vtable;
typedef const struct _jc_soot_Singletons__24Global$vtype	_jc_soot_Singletons__24Global$vtype;

// Constructors
extern void _jc_soot_Singletons__24Global$method$_init$22c85bd733217d1a(_jc_env *, struct _jc_soot_Singletons__24Global$object *, struct _jc_soot_Singletons$object *);
extern void _jc_soot_Singletons__24Global$method$_init$f76d0cd70196eeaa(_jc_env *, struct _jc_soot_Singletons__24Global$object *, struct _jc_soot_Singletons$object *, struct _jc_soot_Singletons__241$object *);

// Virtual methods structure
struct _jc_soot_Singletons__24Global$vmethods {
};

// Vtable
struct _jc_soot_Singletons__24Global$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Singletons__24Global$vmethods	soot_Singletons__24Global;
};

// Vtype
struct _jc_soot_Singletons__24Global$vtype {
	_jc_type			type;
	_jc_soot_Singletons__24Global$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_Singletons__24Global$sub_refs {
	struct _jc_soot_Singletons$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_Singletons__24Global$refs {
    _jc_soot_Singletons__24Global$sub_refs	soot_Singletons__24Global;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_Singletons__24Global$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_Singletons__24Global$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Singletons__24Global$sub_nonrefs	soot_Singletons__24Global;
};

// Object instance structure
struct _jc_soot_Singletons__24Global$object {
	_jc_soot_Singletons__24Global$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_Singletons__24Global$vtype	*vtype;
	_jc_soot_Singletons__24Global$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_Singletons__24Global$vtype _jc_soot_Singletons__24Global$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_Singletons__24Global, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_Singletons__24Global$class_object;

#endif	/* _JC_soot_Singletons__24Global_H_ */

==> jc-1.4.6.tar.gz: soot/Singletons__24Global.h <==
// public final class soot.Singletons$Global

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 47e789a7286ce13e soot_Singletons__24Global

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_Singletons__24Global_H_
#define _JC_soot_Singletons__24Global_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons$object;
struct _jc_soot_Singletons__241$object;

// Typedefs
typedef struct _jc_soot_Singletons__24Global$sub_refs	_jc_soot_Singletons__24Global$sub_refs;
typedef struct _jc_soot_Singletons__24Global$sub_nonrefs	_jc_soot_Singletons__24Global$sub_nonrefs;
typedef struct _jc_soot_Singletons__24Global$refs	_jc_soot_Singletons__24Global$refs;
typedef struct _jc_soot_Singletons__24Global$nonrefs	_jc_soot_Singletons__24Global$nonrefs;
typedef struct _jc_soot_Singletons__24Global$object	_jc_soot_Singletons__24Global$object;

typedef const struct _jc_soot_Singletons__24Global$vmethods	_jc_soot_Singletons__24Global$vmethods;
typedef const struct _jc_soot_Singletons__24Global$vtable	_jc_soot_Singletons__24Global$vtable;
typedef const struct _jc_soot_Singletons__24Global$vtype	_jc_soot_Singletons__24Global$vtype;

// Constructors
extern void _jc_soot_Singletons__24Global$method$_init$22c85bd733217d1a(_jc_env *, struct _jc_soot_Singletons__24Global$object *, struct _jc_soot_Singletons$object *) _JC_JCNI_ATTR;
extern void _jc_soot_Singletons__24Global$method$_init$f76d0cd70196eeaa(_jc_env *, struct _jc_soot_Singletons__24Global$object *, struct _jc_soot_Singletons$object *, struct _jc_soot_Singletons__241$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_Singletons__24Global$vmethods {
};

// Vtable
struct _jc_soot_Singletons__24Global$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Singletons__24Global$vmethods	soot_Singletons__24Global;
};

// Vtype
struct _jc_soot_Singletons__24Global$vtype {
	_jc_type			type;
	_jc_soot_Singletons__24Global$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_Singletons__24Global$sub_refs {
	struct _jc_soot_Singletons$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_Singletons__24Global$refs {
    _jc_soot_Singletons__24Global$sub_refs	soot_Singletons__24Global;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_Singletons__24Global$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_Singletons__24Global$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Singletons__24Global$sub_nonrefs	soot_Singletons__24Global;
};

// Object instance structure
struct _jc_soot_Singletons__24Global$object {
	_jc_soot_Singletons__24Global$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_Singletons__24Global$vtype	*vtype;
	_jc_soot_Singletons__24Global$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_Singletons__24Global$vtype _jc_soot_Singletons__24Global$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_Singletons__24Global, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_Singletons__24Global$class_object;

#endif	/* _JC_soot_Singletons__24Global_H_ */
